{ inputs, config, pkgs, ... }:

{
    imports = [
        (import ./utils/desktop.nix { inherit inputs config pkgs; })
    ];

    programs.ssh.matchBlocks."*".identityFile = "/home/user/.secrets/SSH/Aloria/id_ed25519";

    home.packages = with pkgs; [
        distrobox
        gnome-disk-utility
        moonlight-qt
        vscode
        texliveFull
        zed-editor
        gnome-power-manager
    ];

    services.hyprpaper = {
        settings = {
            wallpaper = [
                "DP-1,${./hyprland/files/wallpaper.png}"
                "DP-5,${./hyprland/files/wallpaper.png}"
                "DP-6,${./hyprland/files/wallpaper.png}"
                "eDP-1,${./hyprland/files/wallpaper.png}"
            ];
        };
    };

    wayland.windowManager.hyprland.settings = {
        monitor = [
            "eDP-1,1920x1080@60,0x0,1"
            "DP-1,1920x1080@60,0x-1080,1"
        ];
        bind = [
            ", XF86PowerOff, exec, ${pkgs.rofi}/bin/rofi -show power-menu -modi power-menu:${
            ./hyprland/files/rofi-power-menu.sh
        }"
        ];
        general.gaps_out = 1;
    };

    programs.alacritty.settings.font.size = 12;
    programs.kitty.font.size = 12;
    programs.zsh.initExtra = pkgs.lib.mkForce ''
      LOCAL_SEARCH_DIRS=(~/.dotfiles/)
      REMOTE_SEARCH_DIRS=( ~/Workspace)
    '';
}
